<!doctype html>
<html>
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{{ title|striptags|e }} — {% if title != 'Skyfield' %}Skyfield {% endif %}documentation</title>
    <link rel="stylesheet" type="text/css" href="_static/style.css">
  </head>
  <body>
    {% if title != 'Skyfield' %}
    <p class="motto">
      <b>Skyfield:</b>
      <a href=".">Home</a>
      •
      <a href="toc.html">Table of Contents</a>
      •
      <a href="installation.html#changelog">Changelog</a>
      •
      <a href="api.html">API Reference</a>
    </p>
    {% endif %}
    {{ body }}
  </body>
</html>
